@@ -66,6 +66,7 @@ class CommandLineInterface:
             }
         }
         self.args = self._parse_arguments()
+        self.run_scope = 'deploy-local-dev' if self.args.local_dev else 'deploy-local'
     
 
     @staticmethod
@@ -92,13 +93,12 @@ class CommandLineInterface:
         )
 
         action_choices = [
+            'new',
             'pre-run',
             'run', 
             'stop', 
-            'create-compose-file', 
             'create-operators-repository',
             'organize', 
-            'run-local-dev', 
             'run-operator-docker', 
             'run-operator-bash', 
         ]
@@ -110,13 +110,6 @@ class CommandLineInterface:
             help=f'action to be executed: {" | ".join(action_choices)}'
         )
 
-        parser.add_argument(
-            "--operators_repository_path",
-            type=str,
-            default="./",
-            help="Path to Operators repository"
-        )
-
         parser.add_argument(
             "--build-images",
             action='store_true',
@@ -129,12 +122,21 @@ class CommandLineInterface:
             help="Publish Docker images to Docker Hub"
         )
 
+        parser.add_argument(
+            "--local-dev",
+            action='store_true',
+            help="Scope of platform run."
+        )
+
         args = parser.parse_args()
 
         return args
     
 
-    def pre_run(self) -> None:
+    def new_platform(self) -> None:
+        """
+        Create basic config-toml file and empty folders for a new local running FlowUI platform.
+        """
         # Create local folder to mount for Airflow home directory
         self.volume_path_airflow_host = Path.cwd() / "airflow"
         if not self.volume_path_airflow_host.is_dir():
@@ -208,10 +210,9 @@ class CommandLineInterface:
         # self.logger.info("Required folders created successfully!")
 
 
-    def run(self) -> None:
+    def pre_run(self) -> None:
         """
-        Run FlowUI using local deploy scope.
-        This will create a docker-compose.yaml file and run it.
+        Will create a docker-compose.yaml file to run an instance of FlowUI locally.
         """
         # Load FlowUI's running instance config.toml
         if Path("config.toml").is_file():
@@ -226,7 +227,6 @@ class CommandLineInterface:
         client = GithubRestClient()
 
         missing_secrets = list()
-        secrets_dict = dict()
         for repo in flowui_config_dict["flowui"]["OPERATORS_REPOSITORIES_NAMES_GITHUB"]:
             # Load compiled metadata
             try:
@@ -259,11 +259,6 @@ class CommandLineInterface:
             # Check if list of secrets defined by Operators repositories are presenti in host's ENV
             for k, v in compiled_metadata.items():
                 secrets_schema = v.get("secrets_schema", None)
-                dep_name = self._get_dependency_for_operator(
-                    operator_name=k, 
-                    dependecies_map=dependencies_map, 
-                    repo_name=repo_name
-                )
                 if secrets_schema:
                     for sn in secrets_schema["properties"].keys():
                         full_secret_name = f"{repo_name}_{sn}"
@@ -273,36 +268,20 @@ class CommandLineInterface:
         if len(missing_secrets) > 0:
             raise MissingEnvVarError(missing_vars=missing_secrets)
 
-        self.create_docker_compose_file(
-            run_scope="deploy-local",
-            flowui_config=flowui_config_dict
+        # TODO - create docker-compose.yml file properly setting:
+        # - mounted volumes for all services
+        self.logger.info("Creating docker-compose.yaml file...")
+        create_docker_compose_file(
+            dependencies_map=dependencies_map,
+            run_scope=self.run_scope,
         )
-
-        # Run docker compose
-        # self.docker = DockerClient(compose_files=["docker-compose.yaml"])
-        # self.docker.compose.up()
+        self.logger.info("docker-compose.yaml file created successfully!")
 
 
-    def _get_dependency_for_operator(self, operator_name: str, dependecies_map: dict, repo_name: str):
+    def run(self) -> None:
         """
-        _summary_
-
-        Args:
-            operator_name (str): _description_
-            dependecies_map (dict): _description_
+        Run FlowUI locally from a previously created docker-compose.yaml file.
         """
-        for k, v in dependecies_map.items():
-            if operator_name in v["operators"]:
-                return k
-        raise NoMatchingDependencyForOperatorError(operator_name=operator_name, repo_name=repo_name)
-
-
-    def run_local_dev(self) -> None:
-        """
-        Run FlowUI using local development environment scope.
-        This will create a docker-compose.yaml file and run it.
-        """ 
-        self.create_docker_compose_file(run_scope="local-dev")
         self.docker = DockerClient(compose_files=["docker-compose.yaml"])
         self.docker.compose.up()
 
@@ -329,14 +308,14 @@ class CommandLineInterface:
         - operators/
         - dependencies/
         """
-        self.operators_path = Path(self.args.operators_repository_path) / "operators"
-        self.dependencies_path = Path(self.args.operators_repository_path) / "dependencies"
-        self.organized_flowui_path = Path(self.args.operators_repository_path) / ".flowui/"
+        self.operators_path = Path(".") / "operators"
+        self.dependencies_path = Path(".") / "dependencies"
+        self.organized_flowui_path = Path(".") / ".flowui/"
         if not self.organized_flowui_path.is_dir():
             self.organized_flowui_path.mkdir(parents=True, exist_ok=True)
         
         # Validating config
-        self.config_path = Path(self.args.operators_repository_path) / 'config.toml'
+        self.config_path = Path(".") / 'config.toml'
         if not self.config_path.is_file():
             self.logger.error("Missing config file")
             raise FileNotFoundError("Missing config file")
@@ -347,7 +326,7 @@ class CommandLineInterface:
         self._validate_config()
         self._validate_env_vars()
 
-        operators_repository = Path(self.args.operators_repository_path)
+        operators_repository = Path(".")
         if not operators_repository.is_dir():
             self.logger.error("Operators repository path does not exist")
             raise Exception("Operators repository path does not exist")
@@ -503,29 +482,10 @@ class CommandLineInterface:
     def _build_docker_images(self) -> None:
         """Convenience function to build Docker images from the repository dependencies and publish them to Docker Hub"""
         self.logger.info("Building Docker images and generating map file...")
-        updated_dependencies_map = build_images_from_operators_repository(
-            operators_repository=self.args.operators_repository_path,
-            publish=self.args.publish_images
-        )
+        updated_dependencies_map = build_images_from_operators_repository(publish=self.args.publish_images)
         return updated_dependencies_map
 
 
-    def create_docker_compose_file(self, run_scope="deploy-local")-> None:
-        """
-        Convenience function to create docker-compose.yaml file in the operators_repository directory.
-
-        Args:
-            run_scope (str): Scope of the run. Default is deploy-local. Options are (deploy-local, local-dev)
-        """
-        self.logger.info("Creating docker-compose.yaml file...")
-        create_docker_compose_file(
-            repository_path=self.args.operators_repository_path,
-            run_scope=run_scope,
-            repository_config=self.config_dict
-        )
-        self.logger.info("docker-compose.yaml file created successfully!")
-
-
     def _create_dependencies_map(self, repo_name: str, save_map_as_file: bool = True) -> None:
         """
         Construct a map between Operators and unique definitions for docker images dependencies
@@ -741,11 +701,10 @@ def cli():
     cli_args = cli.args
     cli_func_map = {        
         # Run locally
+        "new": cli.new_platform,
         "pre-run": cli.pre_run,
         "run": cli.run,
         "stop": cli.stop_compose,
-        "create-compose-file": cli.create_docker_compose_file,
-        "run-local-dev": cli.run_local_dev,
         
         # Operator's repository
         "create-operators-repository": cli.create_operators_repository,
